@@ -128,9 +128,9 @@ impl<'a> AstVisitor<'a> for QueryWriter<'a> {
     }
   }
 
-  fn visit_path(&mut self, path: &Path) {
+  fn visit_absolute_path(&mut self, path: &AbsolutePath) {
     for path_element in path {
-      if is_valid_identifier(path_element) {
+      if is_valid_identifier(&path_element) {
         self.query.push_str(".");
         self.query.push_str(&path_element);
       } else {
@@ -140,6 +140,24 @@ impl<'a> AstVisitor<'a> for QueryWriter<'a> {
     }
   }
 
+  fn visit_wildcard_path(&mut self, path: &WildcardPath) {
+    for path_element in &path.0 {
+      match path_element {
+        PathElement::Field(field) => {
+          if is_valid_identifier(&field) {
+            self.query.push_str(".");
+            self.query.push_str(&field);
+          } else {
+            self.query.push_str(".");
+            self.push_escape_str(&field);
+          }
+        }
+        PathElement::Wildcard => self.query.push_str(".*"),
+        PathElement::RecursiveWildcard => self.query.push_str(".**"),
+      }
+    }
+  }
+
   fn visit_value(&mut self, value: &Value) {
     match *value {
       Value::Null => {
@@ -240,6 +258,14 @@ impl<'a> AstVisitor<'a> for QueryWriter<'a> {
   }
 }
 
+impl ToString for WildcardPath {
+  fn to_string(&self) -> String {
+    let mut writer = QueryWriter::new();
+    writer.visit_wildcard_path(self);
+    writer.query
+  }
+}
+
 impl ToString for Expression {
   fn to_string(&self) -> String {
     let mut writer = QueryWriter::new();
@@ -248,9 +274,9 @@ impl ToString for Expression {
   }
 }
 
-pub fn encode_path(path: &Path) -> String {
+pub fn encode_absolute_path(path: &AbsolutePath) -> String {
   let mut writer = QueryWriter::new();
-  writer.visit_path(path);
+  writer.visit_absolute_path(path);
   writer.query
 }
 
